import { API_ENDPOINTS } from './api-config';

// Typdefinitionen für API-Responses
export interface Printer {
  id: string;
  name: string;
  ip: string;
  status: string;
  is_enabled: boolean;
}

export interface Job {
  id: string;
  printer_id: string;
  user_id: string;
  start_time: string;
  end_time: string;
  status: string;
}

// Fetcher für SWR mit Fehlerbehandlung
const fetchWithErrorHandling = async (url: string) => {
  const response = await fetch(url);
  
  if (!response.ok) {
    const error = new Error('Ein Fehler ist bei der API-Anfrage aufgetreten');
    throw error;
  }
  
  return response.json();
};

// API-Funktionen
export const api = {
  // Drucker-Endpunkte
  printers: {
    getAll: () => fetchWithErrorHandling(API_ENDPOINTS.PRINTERS),
    getById: (id: string) => fetchWithErrorHandling(`${API_ENDPOINTS.PRINTERS}/${id}`),
    create: (data: Partial<Printer>) => 
      fetch(API_ENDPOINTS.PRINTERS, {
        method: 'POST',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify(data),
      }).then(res => res.json()),
    update: (id: string, data: Partial<Printer>) => 
      fetch(`${API_ENDPOINTS.PRINTERS}/${id}`, {
        method: 'PUT',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify(data),
      }).then(res => res.json()),
    delete: (id: string) => 
      fetch(`${API_ENDPOINTS.PRINTERS}/${id}`, {
        method: 'DELETE',
      }).then(res => res.json()),
  },
  
  // Jobs-Endpunkte
  jobs: {
    getAll: () => fetchWithErrorHandling(API_ENDPOINTS.JOBS),
    getById: (id: string) => fetchWithErrorHandling(`${API_ENDPOINTS.JOBS}/${id}`),
    create: (data: Partial<Job>) => 
      fetch(API_ENDPOINTS.JOBS, {
        method: 'POST',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify(data),
      }).then(res => res.json()),
    update: (id: string, data: Partial<Job>) => 
      fetch(`${API_ENDPOINTS.JOBS}/${id}`, {
        method: 'PUT',
        headers: { 'Content-Type': 'application/json' },
        body: JSON.stringify(data),
      }).then(res => res.json()),
    delete: (id: string) => 
      fetch(`${API_ENDPOINTS.JOBS}/${id}`, {
        method: 'DELETE',
      }).then(res => res.json()),
  },
};